@@ -1,4 +1,4 @@
-from servicecatalog_puppet import constants
+from servicecatalog_puppet import constants, config
 
 from servicecatalog_puppet.workflow import provisioning as provisioning_tasks
 
@@ -41,7 +41,8 @@ class SpokeLocalPortfolioSectionTask(manifest_tasks.SectionTask):
                     is_dry_run=self.is_dry_run,
                     depends_on=spoke_local_portfolio.get("depends_on", []),
                     sharing_mode=spoke_local_portfolio.get(
-                        "sharing_mode", constants.SHARING_MODE_ACCOUNT
+                        "sharing_mode",
+                        config.get_global_sharing_mode_default(self.puppet_account_id),
                     ),
                     cache_invalidator=self.cache_invalidator,
                 )
